# Changelog
## 0.0.26 - 2025-03-25
## 0.0.48 - 2025-09-17

* Merge pull request #3 from box-community/rb/users (b1fd38d)
* Update src/box_ai_agents_toolkit/box_api_users.py (310ceda)
* Update src/box_ai_agents_toolkit/box_api_users.py (a9ec88d)
* fix copilot suggestion (9219cd1)
* fix test while loop (e500c9e)
* implementing users list and search (25ebe22)
* Update version to 0.0.47 and changelog (e6719a2)
## 0.0.47 - 2025-09-13

* linting (d61117b)
## 0.0.45 - 2025-08-18

* enable metadata template list (6d88ad6)
* Update version to 0.0.44 and changelog (278042e)
## 0.0.44 - 2025-07-25

* updating readme.md (f5e29d2)
* [AI] removing deprecated ai tools (393f6b1)
* [DOCGE] fix flaky test (0cd5e17)
* [METADATA] fix missing param in creating template (7f9b163)
* [DOCGEN] remove old vibe testing (0eebfd6)
* [RUFF] (ebe9a10)
* [DOCGEN] single file, jobs, and job list (73fcc54)
* [DOCGEN] create batch and single file (065bfc3)
* [DOCGEN] remove old vibe coding test suite (63bf52c)
* [RUFF] (b0c71cc)
* [DOCGEN] implementing template get by name (6458269)
* [DOCGEN] implementing template get by id delete tags and jobs (2c17f08)
* [DOCGEN] implementing template create and list (4904507)
* Update version to 0.0.43 and changelog (d314ee9)
## 0.0.43 - 2025-07-14

* fixing exports (7ec2683)
* metadata template add create template (b035a50)
* metadata template add create template (1ab446f)
* metadata template add create template (036b565)
* metadata template add create template (43e30b6)
* metadata template add create template (7740a7f)
* ruff (83cadb9)
* feature extract structured enhanced using fields and templates (59c506c)
* feature extract structured using fields and templates (30f81b9)
* [REF] AI API - AI ASK + AI Extract freeform (ba47826)
* adding file metadata instance update feature (f363959)
* exposing delete metadata on file (2cf6abb)
* linting (38ec4ad)
* delete metadata file instance (ec12e3a)
* [FIX] make template search by name case insensitive (d718150)
* fixing return dict in find metadata by key and handle api errors and ruffing (63c313f)
* fixing return dict in find metadata by key and handle api errors (4fec330)
* fixing return dict in find metadata by key and handle api errors (b9091c7)
* fixing return dict in find metadata by key (6e26241)
* Box Metadata (752ecf3)
* Box Metadata (857ed8b)
* update (055ba66)
* revert toml (6d6ae47)
* adjust vs (62d0fed)
## 0.0.41 - 2025-04-28

* linting (06b37f9)
## 0.0.38 - 2025-04-04

* [BUG] re-introducing load_doten() to the box authentication (114e0ca)
* Update version to 0.0.37 and changelog (da70739)
## 0.0.37 - 2025-04-04

* [REFACTOR] adding box AI api multiple file dupport (f88be7b)
* [REFACTOR] adding box AI api multiple file dupport (1b98433)
* [REFACTOR] adjusting imports (d693c1b)
* Update version to 0.0.36 and changelog (2cc5134)
## 0.0.36 - 2025-04-04

* [REFACTOR] exposing util classes (a541cfc)
* [REFACTOR] exposing util classes (9600346)
* Update version to 0.0.35 and changelog (35473eb)
## 0.0.35 - 2025-04-04

* [REFACTOR] converting box ai responses into agnostic dictionaries (561e36e)
* major refactor, box api break up, Alex file and folder operations (1c6ac5d)
* Update version to 0.0.34 and changelog (737c965)
## 0.0.34 - 2025-03-25

* exporting box objects (06f2cb7)
* Update version to 0.0.33 and changelog (338b92b)
## 0.0.33 - 2025-03-25

* exporting box objects (03a23dd)
* Update version to 0.0.32 and changelog (6caa55b)
## 0.0.32 - 2025-03-25

* publishing to pypi (3db0199)

* CI/CD script (25e01ee)
* Update version to 0.0.25 and changelog (37902d0)
## 0.0.25 - 2025-03-25

* CI/CD script (7f76549)
* Update version to 0.0.23 and changelog (742d19f)